==> pimd_2.1.1.orig.tar.gz: pimd-2.1.1/pathnames.h <==
/*
 * Copyright (c) 1998-2001
 * University of Southern California/Information Sciences Institute.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the project nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE PROJECT OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
/*
 *  $Id: pathnames.h,v 1.7 2001/09/10 20:31:36 pavlin Exp $
 */
/*
 * Part of this program has been derived from mrouted.
 * The mrouted program is covered by the license in the accompanying file
 * named "LICENSE.mrouted".
 *
 * The mrouted program is COPYRIGHT 1989 by The Board of Trustees of
 * Leland Stanford Junior University.
 *
 */
#ifndef __PIMD_PATHNAMES_H__
#define __PIMD_PATHNAMES_H__

#define _PATH_PIMD_CONF         "/etc/pimd.conf"

#if (defined(BSD) && (BSD >= 199103))
#define _PATH_PIMD_PID          "/var/run/pimd.pid"
#define _PATH_PIMD_GENID        "/var/run/pimd.genid"
#define _PATH_PIMD_DUMP         "/var/tmp/pimd.dump"
#define _PATH_PIMD_CACHE        "/var/tmp/pimd.cache"
#elif defined(Linux)
#define _PATH_PIMD_PID          "/var/run/pimd.pid"
#define _PATH_PIMD_GENID        "/var/run/pimd.genid"
#define _PATH_PIMD_DUMP         "/var/tmp/pimd.dump"
#define _PATH_PIMD_CACHE        "/var/tmp/pimd.cache"
#else
#define _PATH_PIMD_PID          "/etc/pimd.pid"
#define _PATH_PIMD_GENID        "/etc/pimd.genid"
#define _PATH_PIMD_DUMP         "/usr/tmp/pimd.dump"
#define _PATH_PIMD_CACHE        "/usr/tmp/pimd.cache"
#endif

#endif /* __PIMD_PATHNAMES_H__ */

==> pimd_2.1.2-2.tar.gz: pimd-2.1.2/pathnames.h <==
/*
 * Copyright (c) 1998-2001
 * University of Southern California/Information Sciences Institute.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the project nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE PROJECT OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
/*
 * Part of this program has been derived from mrouted.
 * The mrouted program is covered by the license in the accompanying file
 * named "LICENSE.mrouted".
 *
 * The mrouted program is COPYRIGHT 1989 by The Board of Trustees of
 * Leland Stanford Junior University.
 *
 */
#ifndef __PIMD_PATHNAMES_H__
#define __PIMD_PATHNAMES_H__

#define _PATH_PIMD_CONF         "/etc/pimd.conf"

#if (defined(BSD) && (BSD >= 199103)) || defined(__linux__)
#define _PATH_PIMD_DUMP         "/var/tmp/pimd.dump"
#define _PATH_PIMD_CACHE        "/var/tmp/pimd.cache"
#else  /* Really old system ... */
#define _PATH_PIMD_DUMP         "/usr/tmp/pimd.dump"
#define _PATH_PIMD_CACHE        "/usr/tmp/pimd.cache"
#endif

#endif /* __PIMD_PATHNAMES_H__ */
